##  Rate Limits for the Pathfinder API
The [Pathfinder API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DPathfinder "https://app.leanix.net/openapi-explorer/?urls.primaryName=Pathfinder") is the core service that allows you to work with your fact sheets. The API powers data and capabilities behind the fact sheets functionality.
Rate Limits for the Pathfinder API Type | Rate Limit
---|---
User-based rate limit | 1800 requests per minute per user (including both human users and technical users)
Rate limit for internal requests |  1200 requests per minute per workspace for requests from specific internal services listed below. These services automatically reschedule rate-limited requests for you. This applies to:
  * [Import Export API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DImport%2520Export "https://app.leanix.net/openapi-explorer/?urls.primaryName=Import%20Export")
  * [Integration API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DIntegration%2520API "https://app.leanix.net/openapi-explorer/?urls.primaryName=Integration%20API")
  * [Integration ServiceNow API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DIntegration%2520ServiceNow "https://app.leanix.net/openapi-explorer/?urls.primaryName=Integration%20ServiceNow")
  * [Integration Signavio API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%3Furls.primaryName%3DIntegration%2520Signavio "https://app.leanix.net/openapi-explorer/?urls.primaryName=Integration%20Signavio")




